==> ecs-1.60.0-sources.jar: software/amazon/awscdk/services/ecs/ProxyConfigurations.java <==
package software.amazon.awscdk.services.ecs;

/**
 * The base class for proxy configurations.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.9.0 (build 5c646d5)", date = "2020-08-19T23:25:33.034Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ecs.$Module.class, fqn = "@aws-cdk/aws-ecs.ProxyConfigurations")
public class ProxyConfigurations extends software.amazon.jsii.JsiiObject {

    protected ProxyConfigurations(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected ProxyConfigurations(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    public ProxyConfigurations() {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this);
    }

    /**
     * Constructs a new instance of the ProxyConfiguration class.
     * <p>
     * @param props This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ecs.ProxyConfiguration appMeshProxyConfiguration(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ecs.AppMeshProxyConfigurationConfigProps props) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.ecs.ProxyConfigurations.class, "appMeshProxyConfiguration", software.amazon.awscdk.services.ecs.ProxyConfiguration.class, new Object[] { java.util.Objects.requireNonNull(props, "props is required") });
    }
}

==> ecs-1.100.0-sources.jar: software/amazon/awscdk/services/ecs/ProxyConfigurations.java <==
package software.amazon.awscdk.services.ecs;

/**
 * The base class for proxy configurations.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.28.0 (build 1801f4f)", date = "2021-04-20T16:34:41.834Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ecs.$Module.class, fqn = "@aws-cdk/aws-ecs.ProxyConfigurations")
public class ProxyConfigurations extends software.amazon.jsii.JsiiObject {

    protected ProxyConfigurations(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected ProxyConfigurations(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public ProxyConfigurations() {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this);
    }

    /**
     * Constructs a new instance of the ProxyConfiguration class.
     * <p>
     * @param props This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ecs.ProxyConfiguration appMeshProxyConfiguration(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ecs.AppMeshProxyConfigurationConfigProps props) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.ecs.ProxyConfigurations.class, "appMeshProxyConfiguration", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.ecs.ProxyConfiguration.class), new Object[] { java.util.Objects.requireNonNull(props, "props is required") });
    }
}
